
clear all
mata: mata clear
matrix drop _all
set more off
set matsize 10000
set maxvar 32767
set max_memory .
set segmentsize 3g 

* Main folder
cd "/Users/sbrr651/Desktop/JMCB#21-481 - Replication files"
use "data.dta", clear

///////////////////////////////////
//	TABLE 1 - MAIN ESTIMATES 	//
/////////////////////////////////
foreach y in mobint_transaction mob_transaction_alt2 int_transaction account_wdraw_atm account_wdraw_branch { 
	*
	preserve
	drop if age<18

	* Model 1			
	reghdfe `y' pandemic [aweight=wgt] if all==1 & male!=. & urban!=. & children!=. & log_income_4!=. & log_income_4_sq!=. & log_gdppc!=. & gfdddi02!=. & age!=. & education_wp!=. & mstatus!=. & religion!=. & emp_status!=. & inc_decile_ctry!=., absorb(stata_id year) vce(cluster stata_id)			
	outreg2 using "Table1.xml", stats(coef se pval) nocons excel dec(3) addtex(Sample, All, Clustering, Country, Country FE, Yes, Year FE, Yes, Age FE, No, Religion FE, No, Marital FE, No, Education FE, No, Employment FE, No, Income Decile FE, No, Country x Education FE, No, Country x Employment FE, No, Country x Income Dec. FE, No) ///
	keep(pandemic) sortvar(pandemic) noni adjr2 bracket
	
	* Model 2			
	reghdfe `y' pandemic male urban children [aweight=wgt] if all==1 & male!=. & urban!=. & children!=. & log_income_4!=. & log_income_4_sq!=. & log_gdppc!=. & gfdddi02!=. & age!=. & education_wp!=. & mstatus!=. & religion!=. & emp_status!=. & inc_decile_ctry!=., absorb(stata_id year age mstatus religion) vce(cluster stata_id)			
	outreg2 using "Table1.xml", stats(coef se pval) nocons excel dec(3) addtex(Sample, All, Clustering, Country, Country FE, Yes, Year FE, Yes, Age FE, Yes, Religion FE, Yes, Marital FE, Yes, Education FE, No, Employment FE, No, Income Decile FE, No, Country x Education FE, No, Country x Employment FE, No, Country x Income Dec. FE, No) ///
	keep(pandemic) sortvar(pandemic) noni adjr2 bracket
	
	* Model 3			
	reghdfe `y' pandemic male urban children education2 education3 log_income_4 log_income_4_sq [aweight=wgt] if all==1 & male!=. & urban!=. & children!=. & log_income_4!=. & log_income_4_sq!=. & log_gdppc!=. & gfdddi02!=. & age!=. & education_wp!=. & mstatus!=. & religion!=. & emp_status!=. & inc_decile_ctry!=., absorb(stata_id year age mstatus religion emp_status inc_decile_ctry) vce(cluster stata_id)			
	outreg2 using "Table1.xml", stats(coef se pval) nocons excel dec(3) addtex(Sample, All, Clustering, Country, Country FE, Yes, Year FE, Yes, Age FE, Yes, Religion FE, Yes, Marital FE, Yes, Education FE, Yes, Employment FE, Yes, Income Decile FE, Yes, Country x Education FE, No, Country x Employment FE, No, Country x Income Dec. FE, No) ///
	keep(pandemic) sortvar(pandemic) noni adjr2 bracket	
	
	* Model 4			
	reghdfe `y' pandemic male urban children education2 education3 log_income_4 log_income_4_sq log_gdppc gfdddi02 [aweight=wgt] if all==1 & male!=. & urban!=. & children!=. & log_income_4!=. & log_income_4_sq!=. & log_gdppc!=. & gfdddi02!=. & age!=. & education_wp!=. & mstatus!=. & religion!=. & emp_status!=. & inc_decile_ctry!=., absorb(stata_id year age mstatus religion emp_status inc_decile_ctry) vce(cluster stata_id)			
	outreg2 using "Table1.xml", stats(coef se pval) nocons excel dec(3) addtex(Sample, All, Clustering, Country, Country FE, Yes, Year FE, Yes, Age FE, Yes, Religion FE, Yes, Marital FE, Yes, Education FE, Yes, Employment FE, Yes, Income Decile FE, Yes, Country x Education FE, No, Country x Employment FE, No, Country x Income Dec. FE, No) ///
	keep(pandemic) sortvar(pandemic) noni adjr2 bracket		
	
	* Model 5			
	reghdfe `y' pandemic male urban children log_income_4 log_income_4_sq log_gdppc gfdddi02 [aweight=wgt] if all==1 & male!=. & urban!=. & children!=. & log_income_4!=. & log_income_4_sq!=. & log_gdppc!=. & gfdddi02!=. & age!=. & education_wp!=. & mstatus!=. & religion!=. & emp_status!=. & inc_decile_ctry!=., absorb(year age mstatus religion country_edu country_emp country_incdec) vce(cluster stata_id)			
	outreg2 using "Table1.xml", stats(coef se pval) nocons excel dec(3) addtex(Sample, All, Clustering, Country, Country FE, No, Year FE, Yes, Age FE, Yes, Religion FE, Yes, Marital FE, Yes, Education FE, No, Employment FE, No, Income Decile FE, No, Country x Education FE, Yes, Country x Employment FE, Yes, Country x Income Dec. FE, Yes) ///
	keep(pandemic) sortvar(pandemic) noni adjr2 bracket					
	
	restore
	*
}
erase "Table1.txt"


///////////////////////////////////////////
//	TABLE 1 - OSTER VALUES (Column 5) 	//
/////////////////////////////////////////
*
* Outcome: mobint_transaction
* Full model R (r_squared_full): 0.274
* When economic controls dropped R (r_squared_fe): 0.202
* max_r_squared = r_squared_fe + (r_squared_full-r_squared_fe) * 1.3 = 0.296
* Run oster
preserve
drop if age<18
xi:reg mobint_transaction pandemic male urban children log_income_4 log_income_4_sq log_gdppc gfdddi02 countrydum* yearsdum* agedum* marrydum* reldum* country_edudum* country_empdum* country_incdum* [aweight=wgt] if all==1 & male!=. & urban!=. & children!=. & log_income_4!=. & log_income_4_sq!=. & log_gdppc!=. & gfdddi02!=. & age!=. & education_wp!=. & mstatus!=. & religion!=. & emp_status!=. & inc_decile_ctry!=., r cluster (stata_id)		
psacalc delta pandemic, rmax(0.296) mcontrol(male urban children countrydum* yearsdum* agedum* marrydum* reldum*)  
restore
*	
* Outcome: mob_transaction_alt2
* Full model R (r_squared_full): 0.218
* When economic controls dropped R (r_squared_fe): 0.152
* max_r_squared = r_squared_fe + (r_squared_full-r_squared_fe) * 1.3 = 0.238
* Run oster
preserve
drop if age<18
xi:reg mob_transaction_alt2 pandemic male urban children log_income_4 log_income_4_sq log_gdppc gfdddi02 countrydum* yearsdum* agedum* marrydum* reldum* country_edudum* country_empdum* country_incdum* [aweight=wgt] if all==1 & male!=. & urban!=. & children!=. & log_income_4!=. & log_income_4_sq!=. & log_gdppc!=. & gfdddi02!=. & age!=. & education_wp!=. & mstatus!=. & religion!=. & emp_status!=. & inc_decile_ctry!=., r cluster (stata_id)			
psacalc delta pandemic, rmax(0.238) mcontrol(male urban children countrydum* yearsdum* agedum* marrydum* reldum*)  
restore
*	
* Outcome: int_transaction
* Full model R (r_squared_full): 0.418
* When economic controls dropped R (r_squared_fe): 0.343
* max_r_squared = r_squared_fe + (r_squared_full-r_squared_fe) * 1.3 = 0.441
* Run oster
preserve
drop if age<18
xi:reg int_transaction pandemic male urban children log_income_4 log_income_4_sq log_gdppc gfdddi02 countrydum* yearsdum* agedum* marrydum* reldum* country_edudum* country_empdum* country_incdum* [aweight=wgt] if all==1 & male!=. & urban!=. & children!=. & log_income_4!=. & log_income_4_sq!=. & log_gdppc!=. & gfdddi02!=. & age!=. & education_wp!=. & mstatus!=. & religion!=. & emp_status!=. & inc_decile_ctry!=., r cluster (stata_id)				
psacalc delta pandemic, rmax(0.441) mcontrol(male urban children countrydum* yearsdum* agedum* marrydum* reldum*)  
restore
*		
* Outcome: account_wdraw_atm
* Full model R (r_squared_full): 0.346
* When economic controls dropped R (r_squared_fe): 0.281
* max_r_squared = r_squared_fe + (r_squared_full-r_squared_fe) * 1.3 = 0.365
* Run oster
preserve
drop if age<18
xi:reg account_wdraw_atm pandemic male urban children log_income_4 log_income_4_sq log_gdppc gfdddi02 countrydum* yearsdum* agedum* marrydum* reldum* country_edudum* country_empdum* country_incdum* [aweight=wgt] if all==1 & male!=. & urban!=. & children!=. & log_income_4!=. & log_income_4_sq!=. & log_gdppc!=. & gfdddi02!=. & age!=. & education_wp!=. & mstatus!=. & religion!=. & emp_status!=. & inc_decile_ctry!=., r cluster (stata_id)				
psacalc delta pandemic, rmax(0.365) mcontrol(male urban children countrydum* yearsdum* agedum* marrydum* reldum*) 
restore
*		
* Outcome: account_wdraw_branch
* Full model R (r_squared_full): 0.334
* When economic controls dropped R (r_squared_fe): 0.276
* max_r_squared = r_squared_fe + (r_squared_full-r_squared_fe) * 1.3 = 0.351
* Run oster
preserve
drop if age<18
xi:reg account_wdraw_branch pandemic male urban children log_income_4 log_income_4_sq log_gdppc gfdddi02 countrydum* yearsdum* agedum* marrydum* reldum* country_edudum* country_empdum* country_incdum* [aweight=wgt] if all==1 & male!=. & urban!=. & children!=. & log_income_4!=. & log_income_4_sq!=. & log_gdppc!=. & gfdddi02!=. & age!=. & education_wp!=. & mstatus!=. & religion!=. & emp_status!=. & inc_decile_ctry!=., r cluster (stata_id)					
psacalc delta pandemic, rmax(0.351) mcontrol(male urban children countrydum* yearsdum* agedum* marrydum* reldum*) 
restore


///////////////////////////////////
//	TABLE 2 - MAIN ESTIMATES 	//
/////////////////////////////////
foreach y in account_fin account_depo_mth account_wdraw_mth debitcard creditcard  { 
	*
	preserve
	drop if age<18

	* Model 1			
	reghdfe `y' pandemic [aweight=wgt] if all==1 & male!=. & urban!=. & children!=. & log_income_4!=. & log_income_4_sq!=. & log_gdppc!=. & gfdddi02!=. & age!=. & education_wp!=. & mstatus!=. & religion!=. & emp_status!=. & inc_decile_ctry!=., absorb(stata_id year) vce(cluster stata_id)			
	outreg2 using "Table2.xml", stats(coef se pval) nocons excel dec(3) addtex(Sample, All, Clustering, Country, Country FE, Yes, Year FE, Yes, Age FE, No, Religion FE, No, Marital FE, No, Education FE, No, Employment FE, No, Income Decile FE, No, Country x Education FE, No, Country x Employment FE, No, Country x Income Dec. FE, No) ///
	keep(pandemic) sortvar(pandemic) noni adjr2 bracket
	
	* Model 2			
	reghdfe `y' pandemic male urban children [aweight=wgt] if all==1 & male!=. & urban!=. & children!=. & log_income_4!=. & log_income_4_sq!=. & log_gdppc!=. & gfdddi02!=. & age!=. & education_wp!=. & mstatus!=. & religion!=. & emp_status!=. & inc_decile_ctry!=., absorb(stata_id year age mstatus religion) vce(cluster stata_id)			
	outreg2 using "Table2.xml", stats(coef se pval) nocons excel dec(3) addtex(Sample, All, Clustering, Country, Country FE, Yes, Year FE, Yes, Age FE, Yes, Religion FE, Yes, Marital FE, Yes, Education FE, No, Employment FE, No, Income Decile FE, No, Country x Education FE, No, Country x Employment FE, No, Country x Income Dec. FE, No) ///
	keep(pandemic) sortvar(pandemic) noni adjr2 bracket
	
	* Model 3			
	reghdfe `y' pandemic male urban children education2 education3 log_income_4 log_income_4_sq [aweight=wgt] if all==1 & male!=. & urban!=. & children!=. & log_income_4!=. & log_income_4_sq!=. & log_gdppc!=. & gfdddi02!=. & age!=. & education_wp!=. & mstatus!=. & religion!=. & emp_status!=. & inc_decile_ctry!=., absorb(stata_id year age mstatus religion emp_status inc_decile_ctry) vce(cluster stata_id)			
	outreg2 using "Table2.xml", stats(coef se pval) nocons excel dec(3) addtex(Sample, All, Clustering, Country, Country FE, Yes, Year FE, Yes, Age FE, Yes, Religion FE, Yes, Marital FE, Yes, Education FE, Yes, Employment FE, Yes, Income Decile FE, Yes, Country x Education FE, No, Country x Employment FE, No, Country x Income Dec. FE, No) ///
	keep(pandemic) sortvar(pandemic) noni adjr2 bracket	
	
	* Model 4			
	reghdfe `y' pandemic male urban children education2 education3 log_income_4 log_income_4_sq log_gdppc gfdddi02 [aweight=wgt] if all==1 & male!=. & urban!=. & children!=. & log_income_4!=. & log_income_4_sq!=. & log_gdppc!=. & gfdddi02!=. & age!=. & education_wp!=. & mstatus!=. & religion!=. & emp_status!=. & inc_decile_ctry!=., absorb(stata_id year age mstatus religion emp_status inc_decile_ctry) vce(cluster stata_id)			
	outreg2 using "Table2.xml", stats(coef se pval) nocons excel dec(3) addtex(Sample, All, Clustering, Country, Country FE, Yes, Year FE, Yes, Age FE, Yes, Religion FE, Yes, Marital FE, Yes, Education FE, Yes, Employment FE, Yes, Income Decile FE, Yes, Country x Education FE, No, Country x Employment FE, No, Country x Income Dec. FE, No) ///
	keep(pandemic) sortvar(pandemic) noni adjr2 bracket		
	
	* Model 5			
	reghdfe `y' pandemic male urban children log_income_4 log_income_4_sq log_gdppc gfdddi02 [aweight=wgt] if all==1 & male!=. & urban!=. & children!=. & log_income_4!=. & log_income_4_sq!=. & log_gdppc!=. & gfdddi02!=. & age!=. & education_wp!=. & mstatus!=. & religion!=. & emp_status!=. & inc_decile_ctry!=., absorb(year age mstatus religion country_edu country_emp country_incdec) vce(cluster stata_id)			
	outreg2 using "Table2.xml", stats(coef se pval) nocons excel dec(3) addtex(Sample, All, Clustering, Country, Country FE, No, Year FE, Yes, Age FE, Yes, Religion FE, Yes, Marital FE, Yes, Education FE, No, Employment FE, No, Income Decile FE, No, Country x Education FE, Yes, Country x Employment FE, Yes, Country x Income Dec. FE, Yes) ///
	keep(pandemic) sortvar(pandemic) noni adjr2 bracket					
	
	restore
	*
}
erase "Table2.txt"


///////////////////////////////////
//	TABLE 3 - MAIN ESTIMATES 	//
/////////////////////////////////
foreach b in three_g_w dummy3G three_g_wf { 
	*
	preserve
	drop if age<18 

	* Model 1			
	reghdfe mobint_transaction `b'_pandemic `b' pandemic [aweight=wgt] if all==1 & male!=. & urban!=. & children!=. & log_income_4!=. & log_income_4_sq!=. & log_gdppc!=. & gfdddi02!=. & age!=. & education_wp!=. & mstatus!=. & religion!=. & emp_status!=. & inc_decile_ctry!=., absorb(stata_id year) vce(cluster stata_id)			
	outreg2 using "Table3.xml", stats(coef se pval) nocons excel dec(3) addtex(Sample, All, Clustering, Country, Country FE, Yes, Year FE, Yes, Age FE, No, Religion FE, No, Marital FE, No, Education FE, No, Employment FE, No, Income Decile FE, No, Country x Education FE, No, Country x Employment FE, No, Country x Income Dec. FE, No, Country x Year FE, No) ///
	keep(`b'_pandemic `b' pandemic) sortvar(`b'_pandemic `b' pandemic) noni adjr2 bracket
	
	* Model 2			
	reghdfe mobint_transaction `b'_pandemic `b' pandemic male urban children [aweight=wgt] if all==1 & male!=. & urban!=. & children!=. & log_income_4!=. & log_income_4_sq!=. & log_gdppc!=. & gfdddi02!=. & age!=. & education_wp!=. & mstatus!=. & religion!=. & emp_status!=. & inc_decile_ctry!=., absorb(stata_id year age mstatus religion) vce(cluster stata_id)			
	outreg2 using "Table3.xml", stats(coef se pval) nocons excel dec(3) addtex(Sample, All, Clustering, Country, Country FE, Yes, Year FE, Yes, Age FE, Yes, Religion FE, Yes, Marital FE, Yes, Education FE, No, Employment FE, No, Income Decile FE, No, Country x Education FE, No, Country x Employment FE, No, Country x Income Dec. FE, No, Country x Year FE, No) ///
	keep(`b'_pandemic `b' pandemic) sortvar(`b'_pandemic `b' pandemic) noni adjr2 bracket
	
	* Model 3			
	reghdfe mobint_transaction `b'_pandemic `b' pandemic male urban children education2 education3 log_income_4 log_income_4_sq [aweight=wgt] if all==1 & male!=. & urban!=. & children!=. & log_income_4!=. & log_income_4_sq!=. & log_gdppc!=. & gfdddi02!=. & age!=. & education_wp!=. & mstatus!=. & religion!=. & emp_status!=. & inc_decile_ctry!=., absorb(stata_id year age mstatus religion emp_status inc_decile_ctry) vce(cluster stata_id)			
	outreg2 using "Table3.xml", stats(coef se pval) nocons excel dec(3) addtex(Sample, All, Clustering, Country, Country FE, Yes, Year FE, Yes, Age FE, Yes, Religion FE, Yes, Marital FE, Yes, Education FE, Yes, Employment FE, Yes, Income Decile FE, Yes, Country x Education FE, No, Country x Employment FE, No, Country x Income Dec. FE, No, Country x Year FE, No) ///
	keep(`b'_pandemic `b' pandemic) sortvar(`b'_pandemic `b' pandemic) noni adjr2 bracket	
	
	* Model 4			
	reghdfe mobint_transaction `b'_pandemic `b' pandemic male urban children education2 education3 log_income_4 log_income_4_sq log_gdppc gfdddi02 [aweight=wgt] if all==1 & male!=. & urban!=. & children!=. & log_income_4!=. & log_income_4_sq!=. & log_gdppc!=. & gfdddi02!=. & age!=. & education_wp!=. & mstatus!=. & religion!=. & emp_status!=. & inc_decile_ctry!=., absorb(stata_id year age mstatus religion emp_status inc_decile_ctry) vce(cluster stata_id)			
	outreg2 using "Table3.xml", stats(coef se pval) nocons excel dec(3) addtex(Sample, All, Clustering, Country, Country FE, Yes, Year FE, Yes, Age FE, Yes, Religion FE, Yes, Marital FE, Yes, Education FE, Yes, Employment FE, Yes, Income Decile FE, Yes, Country x Education FE, No, Country x Employment FE, No, Country x Income Dec. FE, No, Country x Year FE, No) ///
	keep(`b'_pandemic `b' pandemic) sortvar(`b'_pandemic `b' pandemic) noni adjr2 bracket		
	
	* Model 5			
	reghdfe mobint_transaction `b'_pandemic `b' pandemic male urban children log_income_4 log_income_4_sq log_gdppc gfdddi02 [aweight=wgt] if all==1 & male!=. & urban!=. & children!=. & log_income_4!=. & log_income_4_sq!=. & log_gdppc!=. & gfdddi02!=. & age!=. & education_wp!=. & mstatus!=. & religion!=. & emp_status!=. & inc_decile_ctry!=., absorb(year age mstatus religion country_edu country_emp country_incdec) vce(cluster stata_id)			
	outreg2 using "Table3.xml", stats(coef se pval) nocons excel dec(3) addtex(Sample, All, Clustering, Country, Country FE, No, Year FE, Yes, Age FE, Yes, Religion FE, Yes, Marital FE, Yes, Education FE, No, Employment FE, No, Income Decile FE, No, Country x Education FE, Yes, Country x Employment FE, Yes, Country x Income Dec. FE, Yes, Country x Year FE, No) ///
	keep(`b'_pandemic `b' pandemic) sortvar(`b'_pandemic `b' pandemic) noni adjr2 bracket					

	* Model 6			
	reghdfe mobint_transaction `b'_pandemic `b' male urban children log_income_4 log_income_4_sq [aweight=wgt] if all==1 & male!=. & urban!=. & children!=. & log_income_4!=. & log_income_4_sq!=. & log_gdppc!=. & gfdddi02!=. & age!=. & education_wp!=. & mstatus!=. & religion!=. & emp_status!=. & inc_decile_ctry!=., absorb(country_year age mstatus religion country_edu country_emp country_incdec) vce(cluster stata_id)			
	outreg2 using "Table3.xml", stats(coef se pval) nocons excel dec(3) addtex(Sample, All, Clustering, Country, Country FE, No, Year FE, Yes, Age FE, Yes, Religion FE, Yes, Marital FE, Yes, Education FE, No, Employment FE, No, Income Decile FE, No, Country x Education FE, Yes, Country x Employment FE, Yes, Country x Income Dec. FE, Yes, Country x Year FE, Yes) ///
	keep(`b'_pandemic `b' pandemic) sortvar(`b'_pandemic `b' pandemic) noni adjr2 bracket	
	
	restore
	*
}
erase "Table3.txt"			


///////////////////////////////////////////
//	TABLE 3 - OSTER VALUES (Column 6) 	//
/////////////////////////////////////////
*
* Outcome: three_g_w  X  mobint_transaction
* Full model R (r_squared_full): 0.318
* When economic controls dropped R (r_squared_fe): 0.252
* max_r_squared = r_squared_fe + (r_squared_full-r_squared_fe) * 1.3 = 0.338
* Run oster
preserve
drop if age<18
xi:reg mobint_transaction three_g_w_pandemic three_g_w male urban children log_income_4 log_income_4_sq country_ydum* agedum* marrydum* reldum* country_edudum* country_empdum* country_incdum* [aweight=wgt] if all==1 & male!=. & urban!=. & children!=. & log_income_4!=. & log_income_4_sq!=. & log_gdppc!=. & gfdddi02!=. & age!=. & education_wp!=. & mstatus!=. & religion!=. & emp_status!=. & inc_decile_ctry!=., r cluster (stata_id)		
psacalc delta three_g_w_pandemic, rmax(0.338) mcontrol(male urban children country_ydum* agedum* marrydum* reldum*)  
restore
* Outcome: dummy3G  X  mobint_transaction
* Full model R (r_squared_full): 0.318
* When economic controls dropped R (r_squared_fe): 0.252
* max_r_squared = r_squared_fe + (r_squared_full-r_squared_fe) * 1.3 = 0.338
* Run oster
preserve
drop if age<18
xi:reg mobint_transaction dummy3G_pandemic dummy3G male urban children log_income_4 log_income_4_sq country_ydum* agedum* marrydum* reldum* country_edudum* country_empdum* country_incdum* [aweight=wgt] if all==1 & male!=. & urban!=. & children!=. & log_income_4!=. & log_income_4_sq!=. & log_gdppc!=. & gfdddi02!=. & age!=. & education_wp!=. & mstatus!=. & religion!=. & emp_status!=. & inc_decile_ctry!=., r cluster (stata_id)		
psacalc delta dummy3G_pandemic, rmax(0.338) mcontrol(male urban children country_ydum* agedum* marrydum* reldum*)  
restore
* Outcome: three_g_wf  X  mobint_transaction
* Full model R (r_squared_full): 0.324
* When economic controls dropped R (r_squared_fe): 0.254
* max_r_squared = r_squared_fe + (r_squared_full-r_squared_fe) * 1.3 = 0.345
* Run oster
preserve
drop if age<18
xi:reg mobint_transaction three_g_wf_pandemic three_g_wf male urban children log_income_4 log_income_4_sq country_ydum* agedum* marrydum* reldum* country_edudum* country_empdum* country_incdum* [aweight=wgt] if all==1 & male!=. & urban!=. & children!=. & log_income_4!=. & log_income_4_sq!=. & log_gdppc!=. & gfdddi02!=. & age!=. & education_wp!=. & mstatus!=. & religion!=. & emp_status!=. & inc_decile_ctry!=., r cluster (stata_id)		
psacalc delta three_g_wf_pandemic, rmax(0.345) mcontrol(male urban children country_ydum* agedum* marrydum* reldum*)  
restore	


///////////////////
//	FIGURE 1 	//
/////////////////
*FIGURE 1a

/* This part of the analysis was conducted in R using the following packages and code

###########Causal Forest################

#load packages
library(grf)
library(magrittr)
library(dplyr)
library(ggplot2)
library(cowplot)

#Clear global environment
rm(list = ls())

############################
#Building the causal forest#
############################

#Split the sample to create a training and test data
samplesplit <- sample(2, nrow(data), replace = TRUE, prob = c(0.7,0.3))
df_train <- data[samplesplit==1,] ## Training data
df_test <- data[samplesplit==2,] ## Test data

#Settings
set.seed(1900) #To be able to reproduce results
min.node.size = 10 
sample.fraction = .5
num.trees = 8000 # 2,000 trees for fast computation, increase to 20,000 for actual model
imbalance.penalty = NULL
#mtry = 6 #If turned off using default of {(number variables)^0.5 + 20}
#

#Matrix of covariates from training sample
names(df_train)
X <- data.matrix(data.frame(df_train$age, 
                            df_train$mstatus,
                            df_train$country_emp,
                            df_train$religion,
                            #df_train$country_incdec,
                            df_train$male,
                            df_train$urban,
                            df_train$children,
                            df_train$education2,
                            df_train$education3,
                            df_train$log_income_4,
                            #df_train$log_income_4_sq,
                            df_train$log_gdppc,
                            df_train$gfdddi02))

#Matrix of covariates from test sample
X_test <- data.matrix(data.frame(df_test$age, 
                                 df_test$mstatus,
                                 df_test$country_emp,
                                 df_test$religion,
                                 #df_test$country_incdec,
                                 df_test$male,
                                 df_test$urban,
                                 df_test$children,
                                 df_test$education2,
                                 df_test$education3,
                                 df_test$log_income_4,
                                 #df_test$log_income_4_sq,
                                 df_test$log_gdppc,
                                 df_test$gfdddi02))


#Build the forest
cforest <- causal_forest(X = X, ## covariates,
                         Y = as.matrix(df_train["mobint_transaction"]), ## outcome
                         W = as.matrix(df_train["pandemic"]), ## treatment
                         num.trees = num.trees, 
                         Y.hat = NULL, W.hat = NULL, 
                         sample.fraction = sample.fraction, 
                         num.threads = NULL, 
                         min.node.size = min.node.size, 
                         honesty = TRUE, 
                         ci.group.size = 2, 
                         sample.weights = as.matrix(df_train["wgt"]), #GWP weights, needs to be turned off if equalise the cluster weights
                         clusters = as.matrix(df_train["stata_id"]), #Cluster at the country ID level, 
                         #equalize.cluster.weights = TRUE, #If TRUE, each cluster (country) gets the same weight  
                         seed=1900)
cforest


#Importance

### Importance variable
cforest %>% 
  variable_importance() %>% 
  as.data.frame() %>% 
  mutate(variable = colnames(cforest$X.orig)) %>% 
  arrange(desc(V1))
imp <- variable_importance(cforest)
imp <- as.data.frame(imp[order(imp),])
names(imp)[1] <- "imp"
head(imp)
#Edit these lines below for the chart labels
rownames(imp) <- c("Secondary education", "Male", "Tertiary education", "Marital status", "Children", 
                   "Urban", "Religion", "Log GDP per capita", "Bank deposit to GDP", "Age",
                   "Employment", "Household income") 

png("importance_mobint_transaction_19_1.png")
dotchart(imp$imp, labels = row.names(imp), xlab = "Relative importance") #
dev.off()

*/

*FIGURE 1b
local w = 0		
foreach s in income_gr1 income_gr2 income_gr3 income_gr4 income_gr5    { 
	*
	local w = `w'+1				
	preserve
	drop if age<18 
	* Model 5			
	reghdfe mobint_transaction pandemic male urban children log_income_4 log_income_4_sq log_gdppc gfdddi02 [aweight=wgt] if `s'==1 & male!=. & urban!=. & children!=. & log_income_4!=. & log_income_4_sq!=. & log_gdppc!=. & gfdddi02!=. & age!=. & education_wp!=. & mstatus!=. & religion!=. & emp_status!=. & inc_decile_ctry!=., absorb(year age mstatus religion country_edu country_emp country_incdec) vce(cluster stata_id) level(99)			
	est store income_co`w'
	restore
	*
}
coefplot (income_co1, label(Quintile 1)) (income_co2, label(Quintile 2)) (income_co3, label(Quintile 3)) (income_co4, label(Quintile 4)) (income_co5, label(Quintile 5)), ///
keep(pandemic) yscale(off) title("Treatment heterogeneity based on income quintiles",size(medsmall)) graphregion(color(white)) bgcolor(white) xline(0) cismooth grid(none) ///
mlabel mlabposition(6) format(%9.3f) legend(rows(1))
graph export "Figure1b.png", replace
*FIGURE 1c
local w = 0		
foreach s in employedFT employedPT employedNO    { 
	*
	local w = `w'+1				
	preserve
	drop if age<18 
	* Model 5			
	reghdfe mobint_transaction pandemic male urban children log_income_4 log_income_4_sq log_gdppc gfdddi02 [aweight=wgt] if `s'==1 & male!=. & urban!=. & children!=. & log_income_4!=. & log_income_4_sq!=. & log_gdppc!=. & gfdddi02!=. & age!=. & education_wp!=. & mstatus!=. & religion!=. & emp_status!=. & inc_decile_ctry!=., absorb(year age mstatus religion country_edu country_emp country_incdec) vce(cluster stata_id) level(99)			
	est store emp_co`w'
	restore
	*
}
coefplot (emp_co1, label(Full-time employed)) (emp_co2, label(Part-time employed)) (emp_co3, label(Unemployed/Not in workforce)), ///
keep(pandemic) yscale(off) title("Treatment heterogeneity based on employment status",size(medsmall)) graphregion(color(white)) bgcolor(white) xline(0) cismooth grid(none) ///
mlabel mlabposition(6) format(%9.3f) legend(rows(1))
graph export "Figure1c.png", replace
*FIGURE 1d	
local w = 0		
foreach s in age_gr1 age_gr2 age_gr3 age_gr4 age_gr5    { 
	*
	local w = `w'+1				
	preserve
	drop if age<18 
	* Model 5			
	reghdfe mobint_transaction pandemic male urban children log_income_4 log_income_4_sq log_gdppc gfdddi02 [aweight=wgt] if `s'==1 & male!=. & urban!=. & children!=. & log_income_4!=. & log_income_4_sq!=. & log_gdppc!=. & gfdddi02!=. & age!=. & education_wp!=. & mstatus!=. & religion!=. & emp_status!=. & inc_decile_ctry!=., absorb(year age mstatus religion country_edu country_emp country_incdec) vce(cluster stata_id) level(99)			
	est store age_co`w'
	restore
	*
}
coefplot (age_co1, label(Quintile 1)) (age_co2, label(Quintile 2)) (age_co3, label(Quintile 3)) (age_co4, label(Quintile 4)) (age_co5, label(Quintile 5)), ///
keep(pandemic) yscale(off) title("Treatment heterogeneity based on age quintiles",size(medsmall)) graphregion(color(white)) bgcolor(white) xline(0) cismooth grid(none) ///
mlabel mlabposition(6) format(%9.3f) legend(rows(1))
graph export "Figure1d.png", replace


///////////////////
//	FIGURE 2 	//
/////////////////
*FIGURE 2a
matrix coef = J(5, 3, .)
matrix coln coef = coefficients1 lcl1 ucl1
matrix rown coef = "-2y" "-1y" "Pandemic year" "+1y" "+2y" 	
preserve
drop if age<18
local w = 1
foreach x in f2pandemic f1pandemic pandemic l1pandemic l2pandemic {
	* Model	5
	reghdfe mobint_transaction `x' male urban children log_income_4 log_income_4_sq log_gdppc gfdddi02 [aweight=wgt] if all==1 & male!=. & urban!=. & children!=. & log_income_4!=. & log_income_4_sq!=. & log_gdppc!=. & gfdddi02!=. & age!=. & education_wp!=. & mstatus!=. & religion!=. & emp_status!=. & inc_decile_ctry!=., absorb(year age mstatus religion country_edu country_emp country_incdec) vce(cluster stata_id) level(99)			
	mat os = r(table)
	mat coef[`w',1] = os[1,1]
	mat coef[`w',2] = os[5,1]
	mat coef[`w',3] = os[6,1]
	*
	local w = `w'+1				
}
coefplot (matrix(coef[,1]), ci((coef[,2] coef[,3]))), title("Short-term effect of a pandemic on online/mobile transaction using the internet and bank account",size(small)) graphregion(color(white)) bgcolor(white) vertical yline(0) ///
xline(3, lpattern(shortdash) lcolor(gray)) ciopts(lwidth(vthick) lcolor(navy)) grid(between glpattern(shortdash)) msymbol(S) mfcolor(white) mlabel format(%9.3f) ylabel(,labs(vsmall) format(%9.2f))		
graph export "Figure2a1.png", replace
restore
matrix coef = J(5, 3, .)
matrix coln coef = coefficients1 lcl1 ucl1
matrix rown coef = "-2y" "-1y" "Pandemic year" "+1y" "+2y" 
preserve
drop if age<18
local w = 1
foreach x in f2pandemic f1pandemic pandemic l1pandemic l2pandemic {
	* Model	5
	reghdfe account_wdraw_atm `x' male urban children log_income_4 log_income_4_sq log_gdppc gfdddi02 [aweight=wgt] if all==1 & male!=. & urban!=. & children!=. & log_income_4!=. & log_income_4_sq!=. & log_gdppc!=. & gfdddi02!=. & age!=. & education_wp!=. & mstatus!=. & religion!=. & emp_status!=. & inc_decile_ctry!=., absorb(year age mstatus religion country_edu country_emp country_incdec) vce(cluster stata_id) level(99)			
	mat os = r(table)
	mat coef[`w',1] = os[1,1]
	mat coef[`w',2] = os[5,1]
	mat coef[`w',3] = os[6,1]
	*
	local w = `w'+1				
}
coefplot (matrix(coef[,1]), ci((coef[,2] coef[,3]))), title("Short-term effect of a pandemic on withdrawals using ATM",size(medsmall)) graphregion(color(white)) bgcolor(white) vertical yline(0) ///
xline(3, lpattern(shortdash) lcolor(gray)) ciopts(lwidth(vthick) lcolor(navy)) grid(between glpattern(shortdash)) msymbol(S) mfcolor(white) mlabel format(%9.3f) ylabel(,labs(vsmall) format(%9.2f))		
graph export "Figure2a2.png", replace
restore
matrix coef = J(5, 3, .)
matrix coln coef = coefficients1 lcl1 ucl1
matrix rown coef = "-2y" "-1y" "Pandemic year" "+1y" "+2y" 
preserve
drop if age<18
local w = 1
foreach x in f2pandemic f1pandemic pandemic l1pandemic l2pandemic {
	* Model	5
	reghdfe account_wdraw_branch `x' male urban children log_income_4 log_income_4_sq log_gdppc gfdddi02 [aweight=wgt] if all==1 & male!=. & urban!=. & children!=. & log_income_4!=. & log_income_4_sq!=. & log_gdppc!=. & gfdddi02!=. & age!=. & education_wp!=. & mstatus!=. & religion!=. & emp_status!=. & inc_decile_ctry!=., absorb(year age mstatus religion country_edu country_emp country_incdec) vce(cluster stata_id) level(99)			
	mat os = r(table)
	mat coef[`w',1] = os[1,1]
	mat coef[`w',2] = os[5,1]
	mat coef[`w',3] = os[6,1]
	*
	local w = `w'+1				
}
coefplot (matrix(coef[,1]), ci((coef[,2] coef[,3]))), title("Short-term effect of a pandemic on withdrawals using a bank branch",size(medsmall)) graphregion(color(white)) bgcolor(white) vertical yline(0) ///
xline(3, lpattern(shortdash) lcolor(gray)) ciopts(lwidth(vthick) lcolor(navy)) grid(between glpattern(shortdash)) msymbol(S) mfcolor(white) mlabel format(%9.3f) ylabel(,labs(vsmall) format(%9.2f))		
graph export "Figure2a3.png", replace
restore
*FIGURE 2b
matrix coef = J(5, 3, .)
matrix coln coef = coefficients1 lcl1 ucl1
matrix rown coef = "-2y" "-1y" "Pandemic year" "+1y" "+2y" 	
preserve
drop if age<18
local w = 1
foreach x in f2pandemic f1pandemic pandemic l1pandemic l2pandemic {
	* Model	6 
	reghdfe mobint_transaction three_g_w_`x' three_g_w male urban children log_income_4 log_income_4_sq [aweight=wgt] if all==1 & male!=. & urban!=. & children!=. & log_income_4!=. & log_income_4_sq!=. & log_gdppc!=. & gfdddi02!=. & age!=. & education_wp!=. & mstatus!=. & religion!=. & emp_status!=. & inc_decile_ctry!=., absorb(country_year age mstatus religion country_edu country_emp country_incdec) vce(cluster stata_id) level(99)					
	mat os = r(table)
	mat coef[`w',1] = os[1,1]
	mat coef[`w',2] = os[5,1]
	mat coef[`w',3] = os[6,1]
	*
	local w = `w'+1				
}
coefplot (matrix(coef[,1]), ci((coef[,2] coef[,3]))), title("Short-term effect of a pandemic*3Gaccess on online/mobile transaction using the internet and bank account",size(small)) graphregion(color(white)) bgcolor(white) vertical yline(0) ///
xline(3, lpattern(shortdash) lcolor(gray)) ciopts(lwidth(vthick) lcolor(navy)) grid(between glpattern(shortdash)) msymbol(S) mfcolor(white) mlabel format(%9.3f) ylabel(,labs(vsmall) format(%9.2f))		
graph export "Figure2b1.png", replace
restore
matrix coef = J(5, 3, .)
matrix coln coef = coefficients1 lcl1 ucl1
matrix rown coef = "-2y" "-1y" "Pandemic year" "+1y" "+2y"
preserve
drop if age<18
local w = 1
foreach x in f2pandemic f1pandemic pandemic l1pandemic l2pandemic {
	* Model	6 
	reghdfe mobint_transaction dummy3G_`x' dummy3G male urban children log_income_4 log_income_4_sq [aweight=wgt] if all==1 & male!=. & urban!=. & children!=. & log_income_4!=. & log_income_4_sq!=. & log_gdppc!=. & gfdddi02!=. & age!=. & education_wp!=. & mstatus!=. & religion!=. & emp_status!=. & inc_decile_ctry!=., absorb(country_year age mstatus religion country_edu country_emp country_incdec) vce(cluster stata_id) level(99)					
	mat os = r(table)
	mat coef[`w',1] = os[1,1]
	mat coef[`w',2] = os[5,1]
	mat coef[`w',3] = os[6,1]
	*
	local w = `w'+1				
}
coefplot (matrix(coef[,1]), ci((coef[,2] coef[,3]))), title("Short-term effect of a pandemic*AboveMedian3G on online/mobile transaction using the internet and bank account",size(small)) graphregion(color(white)) bgcolor(white) vertical yline(0) ///
xline(3, lpattern(shortdash) lcolor(gray)) ciopts(lwidth(vthick) lcolor(navy)) grid(between glpattern(shortdash)) msymbol(S) mfcolor(white) mlabel format(%9.3f) ylabel(,labs(vsmall) format(%9.2f))		
graph export "Figure2b2.png", replace
restore
matrix coef = J(5, 3, .)
matrix coln coef = coefficients1 lcl1 ucl1
matrix rown coef = "-2y" "-1y" "Pandemic year" "+1y" "+2y"
preserve
drop if age<18
local w = 1
foreach x in f2pandemic f1pandemic pandemic l1pandemic l2pandemic {
	* Model	6 
	reghdfe mobint_transaction three_g_wf_`x' three_g_wf male urban children log_income_4 log_income_4_sq [aweight=wgt] if all==1 & male!=. & urban!=. & children!=. & log_income_4!=. & log_income_4_sq!=. & log_gdppc!=. & gfdddi02!=. & age!=. & education_wp!=. & mstatus!=. & religion!=. & emp_status!=. & inc_decile_ctry!=., absorb(country_year age mstatus religion country_edu country_emp country_incdec) vce(cluster stata_id) level(99)					
	mat os = r(table)
	mat coef[`w',1] = os[1,1]
	mat coef[`w',2] = os[5,1]
	mat coef[`w',3] = os[6,1]
	*
	local w = `w'+1				
}
coefplot (matrix(coef[,1]), ci((coef[,2] coef[,3]))), title("Short-term effect of a pandemic*3Gaccess2011 on online/mobile transaction using the internet and bank account",size(small)) graphregion(color(white)) bgcolor(white) vertical yline(0) ///
xline(3, lpattern(shortdash) lcolor(gray)) ciopts(lwidth(vthick) lcolor(navy)) grid(between glpattern(shortdash)) msymbol(S) mfcolor(white) mlabel format(%9.3f) ylabel(,labs(vsmall) format(%9.2f))		
graph export "Figure2b3.png", replace
restore


///////////////////////////
//	Appendix TABLE 1  	//
/////////////////////////
foreach x of var mobint_transaction mob_transaction_alt2 int_transaction account_wdraw_atm account_wdraw_branch account_fin account_depo_mth account_wdraw_mth debitcard creditcard  {
	sum `x' if age>17 & pandemic!=. & male!=. & urban!=. & children!=. & log_income_4!=. & log_income_4_sq!=. & log_gdppc!=. & gfdddi02!=. & age!=. & education_wp!=. & mstatus!=. & religion!=. & emp_status!=. & inc_decile_ctry!=.
}
preserve
duplicates drop stata_id year, force
sum pandemic if log_gdppc!=. & gfdddi02!=.
restore 
preserve
duplicates drop districtid year, force
foreach x of var three_g_w three_g_wf {
	sum `x' if log_gdppc!=. & gfdddi02!=.
}
restore 


///////////////////////////
//	Appendix TABLE 2  	//
/////////////////////////
foreach y in   mobint_transaction mob_transaction_alt2 int_transaction account_wdraw_atm account_wdraw_branch     { 
			*
			preserve
			drop if age<18 
			* Model 5			
			reghdfe `y' pandemic_h pandemic_l male urban children log_income_4 log_income_4_sq log_gdppc gfdddi02 [aweight=wgt] if all==1 & male!=. & urban!=. & children!=. & log_income_4!=. & log_income_4_sq!=. & log_gdppc!=. & gfdddi02!=. & age!=. & education_wp!=. & mstatus!=. & religion!=. & emp_status!=. & inc_decile_ctry!=., absorb(year age mstatus religion country_edu country_emp country_incdec) vce(cluster stata_id)			
			outreg2 using "AppendixTable2.xml", stats(coef se pval) nocons excel dec(3) addtex(Sample, All, Clustering, Country, Country FE, No, Year FE, Yes, Age FE, Yes, Religion FE, Yes, Marital FE, Yes, Education FE, No, Employment FE, No, Income Decile FE, No, Country x Education FE, Yes, Country x Employment FE, Yes, Country x Income Dec. FE, Yes) ///
			keep(pandemic_h pandemic_l) sortvar(pandemic_h pandemic_l) noni adjr2 bracket					
			restore
			*
}
erase "AppendixTable2.txt"			


///////////////////////////
//	Appendix TABLE 3  	//
/////////////////////////
foreach y in mobint_transaction mob_transaction_alt2 int_transaction account_wdraw_atm account_wdraw_branch { 
	*
	preserve
	drop if age<18

	* Model 1			
	reghdfe `y' first_exp [aweight=wgt] if all==1 & male!=. & urban!=. & children!=. & log_income_4!=. & log_income_4_sq!=. & log_gdppc!=. & gfdddi02!=. & age!=. & education_wp!=. & mstatus!=. & religion!=. & emp_status!=. & inc_decile_ctry!=., absorb(stata_id year) vce(cluster stata_id)			
	outreg2 using "AppendixTable3.xml", stats(coef se pval) nocons excel dec(3) addtex(Sample, All, Clustering, Country, Country FE, Yes, Year FE, Yes, Age FE, No, Religion FE, No, Marital FE, No, Education FE, No, Employment FE, No, Income Decile FE, No, Country x Education FE, No, Country x Employment FE, No, Country x Income Dec. FE, No) ///
	keep(first_exp) sortvar(first_exp) noni adjr2 bracket
	
	* Model 2			
	reghdfe `y' first_exp male urban children [aweight=wgt] if all==1 & male!=. & urban!=. & children!=. & log_income_4!=. & log_income_4_sq!=. & log_gdppc!=. & gfdddi02!=. & age!=. & education_wp!=. & mstatus!=. & religion!=. & emp_status!=. & inc_decile_ctry!=., absorb(stata_id year age mstatus religion) vce(cluster stata_id)			
	outreg2 using "AppendixTable3.xml", stats(coef se pval) nocons excel dec(3) addtex(Sample, All, Clustering, Country, Country FE, Yes, Year FE, Yes, Age FE, Yes, Religion FE, Yes, Marital FE, Yes, Education FE, No, Employment FE, No, Income Decile FE, No, Country x Education FE, No, Country x Employment FE, No, Country x Income Dec. FE, No) ///
	keep(first_exp) sortvar(first_exp) noni adjr2 bracket
	
	* Model 3			
	reghdfe `y' first_exp male urban children education2 education3 log_income_4 log_income_4_sq [aweight=wgt] if all==1 & male!=. & urban!=. & children!=. & log_income_4!=. & log_income_4_sq!=. & log_gdppc!=. & gfdddi02!=. & age!=. & education_wp!=. & mstatus!=. & religion!=. & emp_status!=. & inc_decile_ctry!=., absorb(stata_id year age mstatus religion emp_status inc_decile_ctry) vce(cluster stata_id)			
	outreg2 using "AppendixTable3.xml", stats(coef se pval) nocons excel dec(3) addtex(Sample, All, Clustering, Country, Country FE, Yes, Year FE, Yes, Age FE, Yes, Religion FE, Yes, Marital FE, Yes, Education FE, Yes, Employment FE, Yes, Income Decile FE, Yes, Country x Education FE, No, Country x Employment FE, No, Country x Income Dec. FE, No) ///
	keep(first_exp) sortvar(first_exp) noni adjr2 bracket	
	
	* Model 4			
	reghdfe `y' first_exp male urban children education2 education3 log_income_4 log_income_4_sq log_gdppc gfdddi02 [aweight=wgt] if all==1 & male!=. & urban!=. & children!=. & log_income_4!=. & log_income_4_sq!=. & log_gdppc!=. & gfdddi02!=. & age!=. & education_wp!=. & mstatus!=. & religion!=. & emp_status!=. & inc_decile_ctry!=., absorb(stata_id year age mstatus religion emp_status inc_decile_ctry) vce(cluster stata_id)			
	outreg2 using "AppendixTable3.xml", stats(coef se pval) nocons excel dec(3) addtex(Sample, All, Clustering, Country, Country FE, Yes, Year FE, Yes, Age FE, Yes, Religion FE, Yes, Marital FE, Yes, Education FE, Yes, Employment FE, Yes, Income Decile FE, Yes, Country x Education FE, No, Country x Employment FE, No, Country x Income Dec. FE, No) ///
	keep(first_exp) sortvar(first_exp) noni adjr2 bracket		
	
	* Model 5			
	reghdfe `y' first_exp male urban children log_income_4 log_income_4_sq log_gdppc gfdddi02 [aweight=wgt] if all==1 & male!=. & urban!=. & children!=. & log_income_4!=. & log_income_4_sq!=. & log_gdppc!=. & gfdddi02!=. & age!=. & education_wp!=. & mstatus!=. & religion!=. & emp_status!=. & inc_decile_ctry!=., absorb(year age mstatus religion country_edu country_emp country_incdec) vce(cluster stata_id)			
	outreg2 using "AppendixTable3.xml", stats(coef se pval) nocons excel dec(3) addtex(Sample, All, Clustering, Country, Country FE, No, Year FE, Yes, Age FE, Yes, Religion FE, Yes, Marital FE, Yes, Education FE, No, Employment FE, No, Income Decile FE, No, Country x Education FE, Yes, Country x Employment FE, Yes, Country x Income Dec. FE, Yes) ///
	keep(first_exp) sortvar(first_exp) noni adjr2 bracket					
	
	restore
	*
}
erase "AppendixTable3.txt"


///////////////////////////
//	Appendix TABLE 4  	//
/////////////////////////
foreach y in mobint_transaction mob_transaction_alt2 int_transaction account_wdraw_atm account_wdraw_branch { 
	*
	preserve
	drop if age<18

	* Model 1			
	reghdfe `y' first_exp2 [aweight=wgt] if all==1 & male!=. & urban!=. & children!=. & log_income_4!=. & log_income_4_sq!=. & log_gdppc!=. & gfdddi02!=. & age!=. & education_wp!=. & mstatus!=. & religion!=. & emp_status!=. & inc_decile_ctry!=., absorb(stata_id year) vce(cluster stata_id)			
	outreg2 using "AppendixTable4.xml", stats(coef se pval) nocons excel dec(3) addtex(Sample, All, Clustering, Country, Country FE, Yes, Year FE, Yes, Age FE, No, Religion FE, No, Marital FE, No, Education FE, No, Employment FE, No, Income Decile FE, No, Country x Education FE, No, Country x Employment FE, No, Country x Income Dec. FE, No) ///
	keep(first_exp2) sortvar(first_exp2) noni adjr2 bracket
	
	* Model 2			
	reghdfe `y' first_exp2 male urban children [aweight=wgt] if all==1 & male!=. & urban!=. & children!=. & log_income_4!=. & log_income_4_sq!=. & log_gdppc!=. & gfdddi02!=. & age!=. & education_wp!=. & mstatus!=. & religion!=. & emp_status!=. & inc_decile_ctry!=., absorb(stata_id year age mstatus religion) vce(cluster stata_id)			
	outreg2 using "AppendixTable4.xml", stats(coef se pval) nocons excel dec(3) addtex(Sample, All, Clustering, Country, Country FE, Yes, Year FE, Yes, Age FE, Yes, Religion FE, Yes, Marital FE, Yes, Education FE, No, Employment FE, No, Income Decile FE, No, Country x Education FE, No, Country x Employment FE, No, Country x Income Dec. FE, No) ///
	keep(first_exp2) sortvar(first_exp2) noni adjr2 bracket
	
	* Model 3			
	reghdfe `y' first_exp2 male urban children education2 education3 log_income_4 log_income_4_sq [aweight=wgt] if all==1 & male!=. & urban!=. & children!=. & log_income_4!=. & log_income_4_sq!=. & log_gdppc!=. & gfdddi02!=. & age!=. & education_wp!=. & mstatus!=. & religion!=. & emp_status!=. & inc_decile_ctry!=., absorb(stata_id year age mstatus religion emp_status inc_decile_ctry) vce(cluster stata_id)			
	outreg2 using "AppendixTable4.xml", stats(coef se pval) nocons excel dec(3) addtex(Sample, All, Clustering, Country, Country FE, Yes, Year FE, Yes, Age FE, Yes, Religion FE, Yes, Marital FE, Yes, Education FE, Yes, Employment FE, Yes, Income Decile FE, Yes, Country x Education FE, No, Country x Employment FE, No, Country x Income Dec. FE, No) ///
	keep(first_exp2) sortvar(first_exp2) noni adjr2 bracket	
	
	* Model 4			
	reghdfe `y' first_exp2 male urban children education2 education3 log_income_4 log_income_4_sq log_gdppc gfdddi02 [aweight=wgt] if all==1 & male!=. & urban!=. & children!=. & log_income_4!=. & log_income_4_sq!=. & log_gdppc!=. & gfdddi02!=. & age!=. & education_wp!=. & mstatus!=. & religion!=. & emp_status!=. & inc_decile_ctry!=., absorb(stata_id year age mstatus religion emp_status inc_decile_ctry) vce(cluster stata_id)			
	outreg2 using "AppendixTable4.xml", stats(coef se pval) nocons excel dec(3) addtex(Sample, All, Clustering, Country, Country FE, Yes, Year FE, Yes, Age FE, Yes, Religion FE, Yes, Marital FE, Yes, Education FE, Yes, Employment FE, Yes, Income Decile FE, Yes, Country x Education FE, No, Country x Employment FE, No, Country x Income Dec. FE, No) ///
	keep(first_exp2) sortvar(first_exp2) noni adjr2 bracket		
	
	* Model 5			
	reghdfe `y' first_exp2 male urban children log_income_4 log_income_4_sq log_gdppc gfdddi02 [aweight=wgt] if all==1 & male!=. & urban!=. & children!=. & log_income_4!=. & log_income_4_sq!=. & log_gdppc!=. & gfdddi02!=. & age!=. & education_wp!=. & mstatus!=. & religion!=. & emp_status!=. & inc_decile_ctry!=., absorb(year age mstatus religion country_edu country_emp country_incdec) vce(cluster stata_id)			
	outreg2 using "AppendixTable4.xml", stats(coef se pval) nocons excel dec(3) addtex(Sample, All, Clustering, Country, Country FE, No, Year FE, Yes, Age FE, Yes, Religion FE, Yes, Marital FE, Yes, Education FE, No, Employment FE, No, Income Decile FE, No, Country x Education FE, Yes, Country x Employment FE, Yes, Country x Income Dec. FE, Yes) ///
	keep(first_exp2) sortvar(first_exp2) noni adjr2 bracket					
	
	restore
	*
}
erase "AppendixTable4.txt"


///////////////////////////
//	Appendix TABLE 5  	//
/////////////////////////
foreach y in mobint_transaction mob_transaction_alt2 int_transaction account_wdraw_atm account_wdraw_branch { 
	*
	preserve
	drop if age<18

	* Model 5 - Clustering at GlobalRegion x Year level 			
	reghdfe `y' pandemic male urban children log_income_4 log_income_4_sq log_gdppc gfdddi02 [aweight=wgt] if all==1 & male!=. & urban!=. & children!=. & log_income_4!=. & log_income_4_sq!=. & log_gdppc!=. & gfdddi02!=. & age!=. & education_wp!=. & mstatus!=. & religion!=. & emp_status!=. & inc_decile_ctry!=., absorb(year age mstatus religion country_edu country_emp country_incdec) vce(cluster region_year)			
	outreg2 using "AppendixTable5.xml", stats(coef se pval) nocons excel dec(3) addtex(Sample, All, Clustering, GlobalRegion x Year, Country FE, No, Year FE, Yes, Age FE, Yes, Religion FE, Yes, Marital FE, Yes, Education FE, No, Employment FE, No, Income Decile FE, No, Country x Education FE, Yes, Country x Employment FE, Yes, Country x Income Dec. FE, Yes, CountryTime Trend, No) ///
	keep(pandemic) sortvar(pandemic) noni adjr2 bracket
	
	* Model 5 - Clustering at GlobalRegion level 			
	reghdfe `y' pandemic male urban children log_income_4 log_income_4_sq log_gdppc gfdddi02 [aweight=wgt] if all==1 & male!=. & urban!=. & children!=. & log_income_4!=. & log_income_4_sq!=. & log_gdppc!=. & gfdddi02!=. & age!=. & education_wp!=. & mstatus!=. & religion!=. & emp_status!=. & inc_decile_ctry!=., absorb(year age mstatus religion country_edu country_emp country_incdec) vce(cluster reg_global)			
	outreg2 using "AppendixTable5.xml", stats(coef se pval) nocons excel dec(3) addtex(Sample, All, Clustering, GlobalRegion, Country FE, No, Year FE, Yes, Age FE, Yes, Religion FE, Yes, Marital FE, Yes, Education FE, No, Employment FE, No, Income Decile FE, No, Country x Education FE, Yes, Country x Employment FE, Yes, Country x Income Dec. FE, Yes, CountryTime Trend, No) ///
	keep(pandemic) sortvar(pandemic) noni adjr2 bracket	
	
	* Model 5 + with CountryTime Trend			
	reghdfe `y' pandemic male urban children log_income_4 log_income_4_sq log_gdppc gfdddi02 country_trend* [aweight=wgt] if all==1 & male!=. & urban!=. & children!=. & log_income_4!=. & log_income_4_sq!=. & log_gdppc!=. & gfdddi02!=. & age!=. & education_wp!=. & mstatus!=. & religion!=. & emp_status!=. & inc_decile_ctry!=., absorb(year age mstatus religion country_edu country_emp country_incdec) vce(cluster stata_id)			
	outreg2 using "AppendixTable5.xml", stats(coef se pval) nocons excel dec(3) addtex(Sample, All, Clustering, Country, Country FE, No, Year FE, Yes, Age FE, Yes, Religion FE, Yes, Marital FE, Yes, Education FE, No, Employment FE, No, Income Decile FE, No, Country x Education FE, Yes, Country x Employment FE, Yes, Country x Income Dec. FE, Yes, CountryTime Trend, Yes) ///
	keep(pandemic) sortvar(pandemic) noni adjr2 bracket					
	
	restore
	*
}
erase "AppendixTable5.txt"


///////////////////////////
//	Appendix TABLE 6  	//
/////////////////////////
foreach y in mobint_transaction mob_transaction_alt2 int_transaction account_wdraw_atm account_wdraw_branch { 
	*
	preserve
	drop if age<18
	
	* Model 5 - Randomising epidemics across the same-continent countries but with the original epidemic year 			
	reghdfe `y' fake_pandemic male urban children log_income_4 log_income_4_sq log_gdppc gfdddi02 [aweight=wgt] if all==1 & male!=. & urban!=. & children!=. & log_income_4!=. & log_income_4_sq!=. & log_gdppc!=. & gfdddi02!=. & age!=. & education_wp!=. & mstatus!=. & religion!=. & emp_status!=. & inc_decile_ctry!=., absorb(year age mstatus religion country_edu country_emp country_incdec) vce(cluster stata_id)			
	outreg2 using "AppendixTable6.xml", stats(coef se pval) nocons excel dec(3) addtex(Sample, All, Clustering, Country, Country FE, No, Year FE, Yes, Age FE, Yes, Religion FE, Yes, Marital FE, Yes, Education FE, No, Employment FE, No, Income Decile FE, No, Country x Education FE, Yes, Country x Employment FE, Yes, Country x Income Dec. FE, Yes) ///
	keep(fake_pandemic fake_pandemic2) sortvar(fake_pandemic fake_pandemic2) noni adjr2 bracket					
	* Model 5 - Randomising epidemics across the same-continent countries and across years
	reghdfe `y' fake_pandemic2 male urban children log_income_4 log_income_4_sq log_gdppc gfdddi02 [aweight=wgt] if all==1 & male!=. & urban!=. & children!=. & log_income_4!=. & log_income_4_sq!=. & log_gdppc!=. & gfdddi02!=. & age!=. & education_wp!=. & mstatus!=. & religion!=. & emp_status!=. & inc_decile_ctry!=., absorb(year age mstatus religion country_edu country_emp country_incdec) vce(cluster stata_id)			
	outreg2 using "AppendixTable6.xml", stats(coef se pval) nocons excel dec(3) addtex(Sample, All, Clustering, Country, Country FE, No, Year FE, Yes, Age FE, Yes, Religion FE, Yes, Marital FE, Yes, Education FE, No, Employment FE, No, Income Decile FE, No, Country x Education FE, Yes, Country x Employment FE, Yes, Country x Income Dec. FE, Yes) ///
	keep(fake_pandemic fake_pandemic2) sortvar(fake_pandemic fake_pandemic2) noni adjr2 bracket					
	
	restore
	*
}
erase "AppendixTable6.txt"


///////////////////////////
//	Appendix TABLE 7  	//
/////////////////////////

use "data2.dta", clear

* Balance Test – Country-level characteristics

* Column 1 

xi: reg pandemic l_gdp_pc_constant2010 l_urbanpopulation l_gfddai05 l_gfddai25_v1  l_gfdddi08  l_gfdddi02  l_gfddei01 l_gfddei04 gfddsi01 gfddsi04 i.year i.country if DTA==1, r 
est sto m1

* Column 2

xi: reg pandemic l_gdp_pc_constant2010 l_urbanpopulation l_gfddai05 l_gfddai25_v1  l_gfdddi08  l_gfdddi02  l_gfddei01 l_gfddei04 gfddsi01 gfddsi04 i.year i.country i.cont_year i.income if DTA==1, r 
est sto m2
 
* Balance Table 2 only for 2011, 2014 and 2017

gen year_findex=year==2011 | year==2014 | year==2017

tab year_findex

* Column 3

xi: reg pandemic l_gdp_pc_constant2010 l_urbanpopulation l_gfddai05 l_gfddai25_v1  l_gfdddi08  l_gfdddi02  l_gfddei01 l_gfddei04 gfddsi01 gfddsi04 i.year i.country if DTA==1 & year_findex==1, r
est sto m3

* Column 4

xi: reg pandemic l_gdp_pc_constant2010 l_urbanpopulation l_gfddai05 l_gfddai25_v1  l_gfdddi08  l_gfdddi02  l_gfddei01 l_gfddei04 gfddsi01 gfddsi04 i.year i.country i.cont_year i.income if DTA==1 & year_findex==1, r 
est sto m4

* Export results
				
		esttab m1 m2 m3 m4   ///
		using "AppendixTable7.xml", replace se r2 b(3) star(* 0.1 ** 0.05 *** 0.01) nocons  ///
		indicate("Country fixed effects = _Icountry_*" "Year fixed effects = _Iyear_*" "Country income group fixed effects = _Iincome_*" "Continent by year fixed effects  = _Icont_year_*") ///
		coef ( l_gdp_pc_constant2010 "GDP per capita (constant 2010 USD) (log)" /// 
		       l_urbanpopulation 	 "Urban population as a share of total pop. (log)" /// 
		       l_gfddai05   		 "Account at a formal financial inst. (% age 15+) (log)" /// 
		       l_gfddai25_v1 		 "ATMs per 100,000 adults (log)" /// 
		       l_gfdddi08 			 "Financial system deposits to GDP (%) (log)" /// 
		       l_gfdddi02 			 "Deposit money banks' assets to GDP (%) (log)"  	///
			   l_gfddei01   		 "Bank net interest margin (%) (log)" /// 
		       l_gfddei04 			 "Bank overhead costs to total assets (%) (log)" /// 
		       gfddsi01 			 "Bank Z-score" /// 
		       gfddsi04 			 "Lerner index"  ) ///
			   order (l_gdp_pc_constant2010 l_urbanpopulation l_gfddai05 l_gfddai25_v1  l_gfdddi08  l_gfdddi02  l_gfddei01 l_gfddei04 gfddsi01 gfddsi04) ///
			   modelwidth(10) varwidth(18) label
		eststo clear 


///////////////////////////
//	Appendix TABLE 8  	//
/////////////////////////

* Balance Test – Country-level characteristics

foreach x in l_gdp_pc_constant2010 l_urbanpopulation l_gfddai05 l_gfddai25_v1  l_gfdddi08  l_gfdddi02  l_gfddei01 l_gfddei04 gfddsi01 gfddsi04 {
by country: gen f_`x' = (`x') if year == 2000
by country: gen l_`x' = (`x') if year == 2017
gen change_`x' = (f_`x'-l_`x')/f_`x'
}


foreach x in f_l_gdp_pc_constant2010 f_l_urbanpopulation f_l_gfddai05 f_l_gfddai25_v1  f_l_gfdddi08  f_l_gfdddi02  f_l_gfddei01 f_l_gfddei04 f_gfddsi01 f_gfddsi04 {
bys country: replace `x' = `x'[_n-1] if `x'== .  
}

gsort country - year

foreach x in l_l_gdp_pc_constant2010 l_l_urbanpopulation l_l_gfddai05 l_l_gfddai25_v1  l_l_gfdddi08  l_l_gfdddi02  l_l_gfddei01 l_l_gfddei04 l_gfddsi01 l_gfddsi04 {
bys country : replace `x' = `x'[_n-1] if `x'== .  
}

foreach x in l_gdp_pc_constant2010 l_urbanpopulation l_gfddai05 l_gfddai25_v1  l_gfdddi08  l_gfdddi02  l_gfddei01 l_gfddei04 gfddsi01 gfddsi04 {
bys country : gen  c_`x' = l_`x'-f_`x'
}

* Column 1

xi: reg pandemic c_* i.country , r
est sto m1

* Column 2

xi: reg pandemic c_* i.country  i.income , r 
est sto m2

* Baseline check 

foreach x in l_gdp_pc_constant2010 l_urbanpopulation l_gfddai05 l_gfddai25_v1  l_gfdddi08  l_gfdddi02  l_gfddei01 l_gfddei04 gfddsi01 gfddsi04 {
by country: gen b_`x' = (`x') if year == 2011
}

gsort country year

foreach x in b_l_gdp_pc_constant2010 b_l_urbanpopulation b_l_gfddai05 b_l_gfddai25_v1  b_l_gfdddi08  b_l_gfdddi02  b_l_gfddei01 b_l_gfddei04 b_gfddsi01 b_gfddsi04 {
bys country : replace `x' = `x'[_n-1] if `x'== .  
} 
 
* Column 3

xi: reg pandemic b_* i.country , r
est sto m3

* Column 4

xi: reg pandemic b_* i.country i.income , r
est sto m4

esttab m1 m2 m3 m4   ///
using "AppendixTable8.xml", replace se r2 b(3) star(* 0.1 ** 0.05 *** 0.01) nocons  ///
indicate("Country fixed effects = _Icountry_*" "Country income group fixed effects = _Iincome_*" ) ///
		coef ( c_l_gdp_pc_constant2010 "GDP per capita (constant 2010 USD) (log)" /// 
		       c_l_urbanpopulation 	 "Urban population as a share of total pop. (log)" /// 
		       c_l_gfddai05   		 "Account at a formal financial inst. (% age 15+) (log)" /// 
		       c_l_gfddai25_v1 		 "ATMs per 100,000 adults (log)" /// 
		       c_l_gfdddi08 			 "Financial system deposits to GDP (%) (log)" /// 
		       c_l_gfdddi02 			 "Deposit money banks' assets to GDP (%) (log)"  	///
			   c_l_gfddei01   		 "Bank net interest margin (%) (log)" /// 
		       c_l_gfddei04 			 "Bank overhead costs to total assets (%) (log)" /// 
		       c_gfddsi01 			 "Bank Z-score" /// 
		       c_gfddsi04 			 "Lerner index" ///
			   b_l_gdp_pc_constant2010 "GDP per capita (constant 2010 USD) (log)" /// 
		       b_l_urbanpopulation 	 "Urban population as a share of total pop. (log)" /// 
		       b_l_gfddai05   		 "Account at a formal financial inst. (% age 15+) (log)" /// 
		       b_l_gfddai25_v1 		 "ATMs per 100,000 adults (log)" /// 
		       b_l_gfdddi08 			 "Financial system deposits to GDP (%) (log)" /// 
		       b_l_gfdddi02 			 "Deposit money banks' assets to GDP (%) (log)"  	///
			   b_l_gfddei01   		 "Bank net interest margin (%) (log)" /// 
		       b_l_gfddei04 			 "Bank overhead costs to total assets (%) (log)" /// 
		       b_gfddsi01 			 "Bank Z-score" /// 
		       b_gfddsi04 			 "Lerner index"  ) ///
			   modelwidth(10) varwidth(18) label
		eststo clear 


* Load individual level data

use "data.dta", clear

///////////////////////////
//	Appendix TABLE 9  	//
/////////////////////////
foreach b in three_g_w dummy3G three_g_wf { 
	*
	preserve
	drop if age<18 
	
	* Model 1			
	reghdfe mobint_transaction `b'_pandemic `b' gsm_w_pandemic gsm_w pandemic [aweight=wgt] if all==1 & male!=. & urban!=. & children!=. & log_income_4!=. & log_income_4_sq!=. & log_gdppc!=. & gfdddi02!=. & age!=. & education_wp!=. & mstatus!=. & religion!=. & emp_status!=. & inc_decile_ctry!=., absorb(stata_id year) vce(cluster stata_id)			
	outreg2 using "AppendixTable9.xml", stats(coef se pval) nocons excel dec(3) addtex(Sample, All, Clustering, Country, Country FE, Yes, Year FE, Yes, Age FE, No, Religion FE, No, Marital FE, No, Education FE, No, Employment FE, No, Income Decile FE, No, Country x Education FE, No, Country x Employment FE, No, Country x Income Dec. FE, No, Country x Year FE, No) ///
	keep(`b'_pandemic `b' gsm_w_pandemic gsm_w pandemic) sortvar(`b'_pandemic `b' gsm_w_pandemic gsm_w pandemic) noni adjr2 bracket
	
	* Model 2			
	reghdfe mobint_transaction `b'_pandemic `b' gsm_w_pandemic gsm_w pandemic male urban children [aweight=wgt] if all==1 & male!=. & urban!=. & children!=. & log_income_4!=. & log_income_4_sq!=. & log_gdppc!=. & gfdddi02!=. & age!=. & education_wp!=. & mstatus!=. & religion!=. & emp_status!=. & inc_decile_ctry!=., absorb(stata_id year age mstatus religion) vce(cluster stata_id)			
	outreg2 using "AppendixTable9.xml", stats(coef se pval) nocons excel dec(3) addtex(Sample, All, Clustering, Country, Country FE, Yes, Year FE, Yes, Age FE, Yes, Religion FE, Yes, Marital FE, Yes, Education FE, No, Employment FE, No, Income Decile FE, No, Country x Education FE, No, Country x Employment FE, No, Country x Income Dec. FE, No, Country x Year FE, No) ///
	keep(`b'_pandemic `b' gsm_w_pandemic gsm_w pandemic) sortvar(`b'_pandemic `b' gsm_w_pandemic gsm_w pandemic) noni adjr2 bracket
	
	* Model 3			
	reghdfe mobint_transaction `b'_pandemic `b' gsm_w_pandemic gsm_w pandemic male urban children education2 education3 log_income_4 log_income_4_sq [aweight=wgt] if all==1 & male!=. & urban!=. & children!=. & log_income_4!=. & log_income_4_sq!=. & log_gdppc!=. & gfdddi02!=. & age!=. & education_wp!=. & mstatus!=. & religion!=. & emp_status!=. & inc_decile_ctry!=., absorb(stata_id year age mstatus religion emp_status inc_decile_ctry) vce(cluster stata_id)			
	outreg2 using "AppendixTable9.xml", stats(coef se pval) nocons excel dec(3) addtex(Sample, All, Clustering, Country, Country FE, Yes, Year FE, Yes, Age FE, Yes, Religion FE, Yes, Marital FE, Yes, Education FE, Yes, Employment FE, Yes, Income Decile FE, Yes, Country x Education FE, No, Country x Employment FE, No, Country x Income Dec. FE, No, Country x Year FE, No) ///
	keep(`b'_pandemic `b' gsm_w_pandemic gsm_w pandemic) sortvar(`b'_pandemic `b' gsm_w_pandemic gsm_w pandemic) noni adjr2 bracket	
	
	* Model 4			
	reghdfe mobint_transaction `b'_pandemic `b' gsm_w_pandemic gsm_w pandemic male urban children education2 education3 log_income_4 log_income_4_sq log_gdppc gfdddi02 [aweight=wgt] if all==1 & male!=. & urban!=. & children!=. & log_income_4!=. & log_income_4_sq!=. & log_gdppc!=. & gfdddi02!=. & age!=. & education_wp!=. & mstatus!=. & religion!=. & emp_status!=. & inc_decile_ctry!=., absorb(stata_id year age mstatus religion emp_status inc_decile_ctry) vce(cluster stata_id)			
	outreg2 using "AppendixTable9.xml", stats(coef se pval) nocons excel dec(3) addtex(Sample, All, Clustering, Country, Country FE, Yes, Year FE, Yes, Age FE, Yes, Religion FE, Yes, Marital FE, Yes, Education FE, Yes, Employment FE, Yes, Income Decile FE, Yes, Country x Education FE, No, Country x Employment FE, No, Country x Income Dec. FE, No, Country x Year FE, No) ///
	keep(`b'_pandemic `b' gsm_w_pandemic gsm_w pandemic) sortvar(`b'_pandemic `b' gsm_w_pandemic gsm_w pandemic) noni adjr2 bracket		
	
	* Model 5			
	reghdfe mobint_transaction `b'_pandemic `b' gsm_w_pandemic gsm_w pandemic male urban children log_income_4 log_income_4_sq log_gdppc gfdddi02 [aweight=wgt] if all==1 & male!=. & urban!=. & children!=. & log_income_4!=. & log_income_4_sq!=. & log_gdppc!=. & gfdddi02!=. & age!=. & education_wp!=. & mstatus!=. & religion!=. & emp_status!=. & inc_decile_ctry!=., absorb(year age mstatus religion country_edu country_emp country_incdec) vce(cluster stata_id)			
	outreg2 using "AppendixTable9.xml", stats(coef se pval) nocons excel dec(3) addtex(Sample, All, Clustering, Country, Country FE, No, Year FE, Yes, Age FE, Yes, Religion FE, Yes, Marital FE, Yes, Education FE, No, Employment FE, No, Income Decile FE, No, Country x Education FE, Yes, Country x Employment FE, Yes, Country x Income Dec. FE, Yes, Country x Year FE, No) ///
	keep(`b'_pandemic `b' gsm_w_pandemic gsm_w pandemic) sortvar(`b'_pandemic `b' gsm_w_pandemic gsm_w pandemic) noni adjr2 bracket					

	* Model 6			
	reghdfe mobint_transaction `b'_pandemic `b' gsm_w_pandemic gsm_w male urban children log_income_4 log_income_4_sq [aweight=wgt] if all==1 & male!=. & urban!=. & children!=. & log_income_4!=. & log_income_4_sq!=. & log_gdppc!=. & gfdddi02!=. & age!=. & education_wp!=. & mstatus!=. & religion!=. & emp_status!=. & inc_decile_ctry!=., absorb(country_year age mstatus religion country_edu country_emp country_incdec) vce(cluster stata_id)			
	outreg2 using "AppendixTable9.xml", stats(coef se pval) nocons excel dec(3) addtex(Sample, All, Clustering, Country, Country FE, No, Year FE, Yes, Age FE, Yes, Religion FE, Yes, Marital FE, Yes, Education FE, No, Employment FE, No, Income Decile FE, No, Country x Education FE, Yes, Country x Employment FE, Yes, Country x Income Dec. FE, Yes, Country x Year FE, Yes) ///
	keep(`b'_pandemic `b' gsm_w_pandemic gsm_w pandemic) sortvar(`b'_pandemic `b' gsm_w_pandemic gsm_w pandemic) noni adjr2 bracket	
	
	restore
	*
}
erase "AppendixTable9.txt"			


///////////////////////////
//	Appendix TABLE 10  	//
/////////////////////////
foreach y in mobint_transaction mob_transaction_alt2 int_transaction account_wdraw_atm account_wdraw_branch { 
	foreach x in 68 83 100 110 129 149 153 164 188 189 { 
		*
		preserve
		drop if age<18 
		
		* Model 5			
		reghdfe `y' pandemic_ex`x' male urban children log_income_4 log_income_4_sq log_gdppc gfdddi02 [aweight=wgt] if all==1 & male!=. & urban!=. & children!=. & log_income_4!=. & log_income_4_sq!=. & log_gdppc!=. & gfdddi02!=. & age!=. & education_wp!=. & mstatus!=. & religion!=. & emp_status!=. & inc_decile_ctry!=., absorb(year age mstatus religion country_edu country_emp country_incdec) vce(cluster stata_id)			
		outreg2 using "AppendixTable10.xml", stats(coef se pval) nocons excel dec(3) addtex(Sample, All, Clustering, Country, Country FE, No, Year FE, Yes, Age FE, Yes, Religion FE, Yes, Marital FE, Yes, Education FE, No, Employment FE, No, Income Decile FE, No, Country x Education FE, Yes, Country x Employment FE, Yes, Country x Income Dec. FE, Yes, Excluded country ID, `x') ///
		keep(pandemic_ex`x') sortvar(pandemic_ex`x') noni adjr2 bracket					
		
		restore
		*
	}
}
erase "AppendixTable10.txt"				


///////////////////////////
//	Appendix TABLE 11  	//
/////////////////////////
foreach y in mobint_transaction mob_transaction_alt2 int_transaction account_wdraw_atm account_wdraw_branch { 
	foreach x in 68 83 100 110 129 149 153 164 188 189 { 
		*
		preserve
		drop if age<18 
		drop if stata_id==`x'
		
		* Model 5			
		reghdfe `y' pandemic male urban children log_income_4 log_income_4_sq log_gdppc gfdddi02 [aweight=wgt] if all==1 & male!=. & urban!=. & children!=. & log_income_4!=. & log_income_4_sq!=. & log_gdppc!=. & gfdddi02!=. & age!=. & education_wp!=. & mstatus!=. & religion!=. & emp_status!=. & inc_decile_ctry!=., absorb(year age mstatus religion country_edu country_emp country_incdec) vce(cluster stata_id)			
		outreg2 using "AppendixTable11.xml", stats(coef se pval) nocons excel dec(3) addtex(Sample, All, Clustering, Country, Country FE, No, Year FE, Yes, Age FE, Yes, Religion FE, Yes, Marital FE, Yes, Education FE, No, Employment FE, No, Income Decile FE, No, Country x Education FE, Yes, Country x Employment FE, Yes, Country x Income Dec. FE, Yes, Dropped country ID, `x') ///
		keep(pandemic) sortvar(pandemic) noni adjr2 bracket					
		
		restore
		*
	}
}
erase "AppendixTable11.txt"	


///////////////////////////
//	Appendix TABLE 12  	//
/////////////////////////

use "data2.dta", clear

* The outcome is ATM per 100,000 people

xi: reg gfddai25_v1 pandemic l_gdp_pc_constant2010 l_urbanpopulation l_gfddai05  l_gfdddi08  l_gfdddi02  l_gfddei01 l_gfddei04 gfddsi01 gfddsi04 i.year i.country if DTA==1, r 
est sto m1

xi: reg gfddai25_v1 pandemic l_gdp_pc_constant2010 l_urbanpopulation l_gfddai05  l_gfdddi08  l_gfdddi02  l_gfddei01 l_gfddei04 gfddsi01 gfddsi04 i.year i.country i.cont_year i.income if DTA==1, r 
est sto m2

* Balance Table 2 only for 2011, 2014 and 2017
gen year_findex=year==2011 | year==2014 | year==2017
tab year_findex

xi: reg gfddai25_v1 pandemic l_gdp_pc_constant2010 l_urbanpopulation l_gfddai05  l_gfdddi08  l_gfdddi02  l_gfddei01 l_gfddei04 gfddsi01 gfddsi04 i.year i.country if DTA==1 & year_findex==1, r
est sto m3

xi: reg gfddai25_v1 pandemic l_gdp_pc_constant2010 l_urbanpopulation l_gfddai05  l_gfdddi08  l_gfdddi02  l_gfddei01 l_gfddei04 gfddsi01 gfddsi04 i.year i.country i.cont_year i.income if DTA==1 & year_findex==1, r 
est sto m4
 
esttab m1 m2 m3 m4   ///
using "AppendixTable12.xml", replace se r2 b(3) star(* 0.1 ** 0.05 *** 0.01) nocons  ///
		indicate("Country fixed effects = _Icountry_*" "Year fixed effects = _Iyear_*" "Country income group fixed effects = _Iincome_*" "Continent by year fixed effects  = _Icont_year_*") ///		
		coef ( l_gdp_pc_constant2010 "GDP per capita (constant 2010 USD) (log)" /// 
		       l_urbanpopulation 	 "Urban population as a share of total pop. (log)" /// 
		       l_gfddai05   		 "Account at a formal financial inst. (% age 15+) (log)" /// 
		       l_gfddai25_v1 		 "ATMs per 100,000 adults (log)" /// 
		       l_gfdddi08 			 "Financial system deposits to GDP (%) (log)" /// 
		       l_gfdddi02 			 "Deposit money banks' assets to GDP (%) (log)"  	///
			   l_gfddei01   		 "Bank net interest margin (%) (log)" /// 
		       l_gfddei04 			 "Bank overhead costs to total assets (%) (log)" /// 
		       gfddsi01 			 "Bank Z-score" /// 
		       gfddsi04 			 "Lerner index"  ) ///
			   modelwidth(10) varwidth(18) label
		eststo clear 

























